@@ -402,17 +402,11 @@ class ContrastiveModel(tf.keras.Model):
             p2 = self.predictor(z2, training=training)
             l1 = self.compiled_loss(tf.stop_gradient(z1), p2)
             l2 = self.compiled_loss(tf.stop_gradient(z2), p1)
+            loss = l1 + l2
             pred1, pred2 = p1, p2
-        elif self.algorithm == "simclr":
-            l1 = self.compiled_loss(z1, z2)
-            l2 = self.compiled_loss(z2, z1)
+        elif self.algorithm in ["simclr", "barlow"]:
+            loss = self.compiled_loss(z1, z2)
             pred1, pred2 = z1, z2
-        elif self.algorithm == "barlow":
-            l1 = self.compiled_loss(z1, z2)
-            l2 = 0
-            pred1, pred2 = z1, z2
-
-        loss = l1 + l2
 
         return loss, pred1, pred2, z1, z2
 
